@@ -30,7 +30,9 @@ public:
   std::unordered_map<size_t, double> compute_weights(size_t sample,
                                                      const Forest& forest,
                                                      const std::vector<std::vector<size_t>>& leaf_nodes_by_tree,
-                                                     const std::vector<std::vector<bool>>& valid_trees_by_sample) const;
+                                                     const std::vector<std::vector<bool>>& valid_trees_by_sample, 
+                                                     const size_t tree_index_start, 
+                                                     const size_t tree_index_end) const;
 
 private:
   void add_sample_weights(const std::vector<size_t>& samples,
